DO NOT REPLY [Bug 40626] New: - HP OpenView Tomcat(A) Servlet Container Service causing the System Clock to run faster than normal

2006-09-28 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG·
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND·
INSERTED IN THE BUG DATABASE.

http://issues.apache.org/bugzilla/show_bug.cgi?id=40626

   Summary: HP OpenView Tomcat(A) Servlet Container Service causing
the System Clock to run faster than normal
   Product: Tomcat 5
   Version: 5.0.1
  Platform: HP
OS/Version: Windows Server 2003
Status: NEW
  Severity: critical
  Priority: P1
 Component: Servlets:CGI
AssignedTo: tomcat-dev@jakarta.apache.org
ReportedBy: [EMAIL PROTECTED]
CC: [EMAIL PROTECTED]


Hi,

We are from HewlettPackard Openview Team. 
The issue here is from Tomcat(A) Servlet Container packaged for HP OpenView 
Internet Services.And our client is experiencig a serious issue cause of the 
TOMCAT SERVICE , the system Clock is running faster than normal , and causing 
advese effects on our Monitoring tool. We need help at the earliest with this 
issue...

Regards,
Subramanya
Telephone #91 80 2205 1542
Mobile # 91 9880542589

-- 
Configure bugmail: http://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug, or are watching the assignee.

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



DO NOT REPLY [Bug 38898] - Tomcat service fails without error message

2006-09-28 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG·
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND·
INSERTED IN THE BUG DATABASE.

http://issues.apache.org/bugzilla/show_bug.cgi?id=38898


[EMAIL PROTECTED] changed:

   What|Removed |Added

 CC||[EMAIL PROTECTED]




--- Additional Comments From [EMAIL PROTECTED]  2006-09-28 07:27 ---
I am honestly not sure this is a Tomcat bug (I'm not a Tomcat committer), but
what I _CAN_ say is that we too are using Tomcat 5.5.15 in production on Red Hat
EL4, and every 2-3 days get a VM abort with this sort of error message
(different memory request size though), so I thought I would share our 
experience.

We have java 1.5.0_07, client VM, startup command looks like this:

/aconex/java/bin/java -client -Xms1600m -Xmx1600m
-XX:+HeapDumpOnOutOfMemoryError -XX:PermSize=128m -XX:MaxPermSize=128m
-Dfile.encoding=utf-8 -Dcom.sun.management.jmxremote.port=
-Dcom.sun.management.jmxremote.authenticate=false
-Dcom.sun.management.jmxremote.ssl=false
-Djava.util.logging.manager=org.apache.juli.ClassLoaderLogManager
-Djava.util.logging.config.file=/aconex/tomcat/conf/logging.properties
-Djava.endorsed.dirs=/aconex/tomcat/common/endorsed -classpath
:/aconex/tomcat/bin/bootstrap.jar:/aconex/tomcat/bin/commons-logging-api.jar
-Dcatalina.base=/aconex/tomcat -Dcatalina.home=/aconex/tomcat
-Djava.io.tmpdir=/aconex/tomcat/temp org.apache.catalina.startup.Bootstrap
-config conf/mel.xml start

We have swap configured (4Gb physical RAM, 4Gb swap).

The virtual memory size of the process grows over time until somewhere between
2.8 and 3Gb before it aborts with this error.

We don't see a hs_err.log file generated either.

I honestly think this is a Java VM bug, but I have no clue what is causing it. 
If anyone else has any info to add to this I'm sure we would all be greatful.

-- 
Configure bugmail: http://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug, or are watching the assignee.

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



svn commit: r450737 - /tomcat/connectors/trunk/jni/native/src/poll.c

2006-09-28 Thread mturk
Author: mturk
Date: Thu Sep 28 00:40:37 2006
New Revision: 450737

URL: http://svn.apache.org/viewvc?view=rev&rev=450737
Log:
Fix #40525. When the Poll.create ttl was < 0 the
Poll.pool was returning immediately instead considering
this as infinite timeout and using provided timeout
param. Also the Poll.maintain was not considering the
ttl == 0, while it should maintain all sockets.

Modified:
tomcat/connectors/trunk/jni/native/src/poll.c

Modified: tomcat/connectors/trunk/jni/native/src/poll.c
URL: 
http://svn.apache.org/viewvc/tomcat/connectors/trunk/jni/native/src/poll.c?view=diff&rev=450737&r1=450736&r2=450737
==
--- tomcat/connectors/trunk/jni/native/src/poll.c (original)
+++ tomcat/connectors/trunk/jni/native/src/poll.c Thu Sep 28 00:40:37 2006
@@ -178,7 +178,11 @@
 fd.reqevents = (apr_int16_t)reqevents;
 fd.desc.s= s->sock;
 fd.client_data = s;
-p->socket_ttl[p->nelts] = apr_time_now();
+if (p->max_ttl > 0)
+p->socket_ttl[p->nelts] = apr_time_now();
+else
+p->socket_ttl[p->nelts] = 0;
+
 p->socket_set[p->nelts] = fd;
 p->nelts++;
 #ifdef TCN_DO_STATISTICS
@@ -219,6 +223,18 @@
 return apr_pollset_remove(p->pollset, fd);
 }
 
+static void remove_all(tcn_pollset_t *p)
+{
+apr_int32_t i;
+for (i = 0; i < p->nelts; i++) {
+apr_pollset_remove(p->pollset, &(p->socket_set[i]));
+#ifdef TCN_DO_STATISTICS
+p->sp_removed++;
+#endif
+}
+p->nelts = 0;
+}
+
 TCN_IMPLEMENT_CALL(jint, Poll, remove)(TCN_STDARGS, jlong pollset,
jlong socket)
 {
@@ -257,7 +273,7 @@
  p->sp_poll++;
 #endif
 
-if (timeout > 0) {
+if (ptime > 0 && p->max_ttl >= 0) {
 apr_time_t now = apr_time_now();
 
 /* Find the minimum timeout */
@@ -272,6 +288,8 @@
 }
 }
 }
+else if (ptime < 0)
+ptime = 0;
 for (;;) {
 rv = apr_pollset_poll(p->pollset, ptime, &num, &fd);
 if (rv != APR_SUCCESS) {
@@ -341,6 +359,19 @@
 fd.desc.s = (J2P(p->set[i], tcn_socket_t *))->sock;
 do_remove(p, &fd);
 }
+}
+}
+else if (p->max_ttl == 0) {
+for (i = 0; i < p->nelts; i++) {
+fd = p->socket_set[i];
+p->set[num++] = P2J(fd.client_data);
+}
+if (remove) {
+remove_all(p);
+#ifdef TCN_DO_STATISTICS
+p->sp_maintained += num;
+p->sp_max_maintained = TCN_MAX(p->sp_max_maintained, num);
+#endif
 }
 }
 if (num)



-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



DO NOT REPLY [Bug 40525] - Native library causes 100% cpu use when idle

2006-09-28 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG·
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND·
INSERTED IN THE BUG DATABASE.

http://issues.apache.org/bugzilla/show_bug.cgi?id=40525


[EMAIL PROTECTED] changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||FIXED




--- Additional Comments From [EMAIL PROTECTED]  2006-09-28 07:38 ---
Fixed in the SVN trunk, although the patch aplied is slightly different.

-- 
Configure bugmail: http://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug, or are watching the assignee.

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



svn commit: r450741 - /tomcat/connectors/trunk/jni/native/include/tcn_version.h

2006-09-28 Thread mturk
Author: mturk
Date: Thu Sep 28 00:46:28 2006
New Revision: 450741

URL: http://svn.apache.org/viewvc?view=rev&rev=450741
Log:
Prepare to TAG 1.1.5

Modified:
tomcat/connectors/trunk/jni/native/include/tcn_version.h

Modified: tomcat/connectors/trunk/jni/native/include/tcn_version.h
URL: 
http://svn.apache.org/viewvc/tomcat/connectors/trunk/jni/native/include/tcn_version.h?view=diff&rev=450741&r1=450740&r2=450741
==
--- tomcat/connectors/trunk/jni/native/include/tcn_version.h (original)
+++ tomcat/connectors/trunk/jni/native/include/tcn_version.h Thu Sep 28 
00:46:28 2006
@@ -74,7 +74,7 @@
  *  This symbol is defined for internal, "development" copies of TCN. This
  *  symbol will be #undef'd for releases.
  */
-#define TCN_IS_DEV_VERSION
+#undef TCN_IS_DEV_VERSION
 
 
 /** The formatted string of APU's version */



-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



svn commit: r450777 - /tomcat/connectors/trunk/jni/jnirelease.sh

2006-09-28 Thread mturk
Author: mturk
Date: Thu Sep 28 02:47:44 2006
New Revision: 450777

URL: http://svn.apache.org/viewvc?view=rev&rev=450777
Log:
Fix release process. The sources will from now have
the -src in the path like APR has.

Modified:
tomcat/connectors/trunk/jni/jnirelease.sh

Modified: tomcat/connectors/trunk/jni/jnirelease.sh
URL: 
http://svn.apache.org/viewvc/tomcat/connectors/trunk/jni/jnirelease.sh?view=diff&rev=450777&r1=450776&r2=450777
==
--
svn:executable = *



-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



DO NOT REPLY [Bug 40606] - Excessive CPU usage

2006-09-28 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG·
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND·
INSERTED IN THE BUG DATABASE.

http://issues.apache.org/bugzilla/show_bug.cgi?id=40606





--- Additional Comments From [EMAIL PROTECTED]  2006-09-28 10:39 ---
FYI. I didn't find 40525 before filing this bug. Thread dump and further 
search did help.

In my test environment I have patched native connectors and rebuild them with 
VC2003. It solved my problem.

greg


-- 
Configure bugmail: http://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug, or are watching the assignee.

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



DO NOT REPLY [Bug 40626] - HP OpenView Tomcat(A) Servlet Container Service causing the System Clock to run faster than normal

2006-09-28 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG·
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND·
INSERTED IN THE BUG DATABASE.

http://issues.apache.org/bugzilla/show_bug.cgi?id=40626


[EMAIL PROTECTED] changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||INVALID




--- Additional Comments From [EMAIL PROTECTED]  2006-09-28 10:55 ---
Bugzilla is not a support group for debugging. Please use the tomcat-users 
mailing list.

Other issues with this bug
1) Component listed is wrong
2) no debugging provided to prove tomcat has a bug
3) Version is incorrect

Odds are - the developers group in HP which maintains openview needs to look at 
this to determine how a fast clock can interfere with openview's monitoring. Or 
look to HP's JVM group since HP bundles their own JVM with HP-UX boxes - if 
this a time vs JVM issue.




-- 
Configure bugmail: http://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug, or are watching the assignee.

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



DO NOT REPLY [Bug 40606] - Excessive CPU usage

2006-09-28 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG·
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND·
INSERTED IN THE BUG DATABASE.

http://issues.apache.org/bugzilla/show_bug.cgi?id=40606





--- Additional Comments From [EMAIL PROTECTED]  2006-09-28 11:09 ---
Can you try the trunk?

-- 
Configure bugmail: http://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug, or are watching the assignee.

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



DO NOT REPLY [Bug 28222] - getRequestURL() in forwarded jsp/servlet doesn't return new url

2006-09-28 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG·
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND·
INSERTED IN THE BUG DATABASE.

http://issues.apache.org/bugzilla/show_bug.cgi?id=28222


[EMAIL PROTECTED] changed:

   What|Removed |Added

 CC||[EMAIL PROTECTED]




-- 
Configure bugmail: http://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug, or are watching the assignee.

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



DO NOT REPLY [Bug 40606] - Excessive CPU usage

2006-09-28 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG·
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND·
INSERTED IN THE BUG DATABASE.

http://issues.apache.org/bugzilla/show_bug.cgi?id=40606





--- Additional Comments From [EMAIL PROTECTED]  2006-09-28 12:57 ---
It works OK

greg

-- 
Configure bugmail: http://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug, or are watching the assignee.

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



svn commit: r450870 - /tomcat/site/trunk/docs/download-55.html

2006-09-28 Thread fhanik
Author: fhanik
Date: Thu Sep 28 07:35:43 2006
New Revision: 450870

URL: http://svn.apache.org/viewvc?view=rev&rev=450870
Log:
Added in Tomcat 5.5.20 as the default download

Modified:
tomcat/site/trunk/docs/download-55.html

Modified: tomcat/site/trunk/docs/download-55.html
URL: 
http://svn.apache.org/viewvc/tomcat/site/trunk/docs/download-55.html?view=diff&rev=450870&r1=450869&r2=450870
==
--- tomcat/site/trunk/docs/download-55.html (original)
+++ tomcat/site/trunk/docs/download-55.html Thu Sep 28 07:35:43 2006
@@ -3,16 +3,16 @@
 
 
 Apache Tomcat - Apache Tomcat 5 Downloads
-
+
 
-
-
+
+
 
 
 
 
 http://tomcat.apache.org/";>
-
+
 
 
 
@@ -23,28 +23,28 @@
 
 
 http://www.apache.org/";>
-http://www.apache.org/images/asf-logo.gif"; />
+http://www.apache.org/images/asf-logo.gif"; align="right" alt="Apache 
Logo" border="0"/>
 
 
 
 
 
-http://www.google.com/search";>
-
-
-
+http://www.google.com/search"; method="get">
+
+
+
 
 
-
+
 
 
 
-
+
 
 
 
 
-
+
 
 Apache Tomcat
 
@@ -155,11 +155,11 @@
 
 
 
-
-
+
+
 
 
-
+
 
 Tomcat 5 Downloads
 
@@ -180,14 +180,14 @@
 
 
 
-
+
 
 
 
-
+
 
 
-
+
 
 Quick Navigation
 
@@ -199,7 +199,7 @@
 
 
 http://www.apache.org/dist/tomcat/tomcat-5/KEYS";>KEYS |
-5.5.17 |
+5.5.20 |
 5.0.30-beta |
 5.0.28 |
 http://archive.apache.org/dist/tomcat/tomcat-5";>Archives
@@ -209,14 +209,14 @@
 
 
 
-
+
 
 
 
-
+
 
 
-
+
 
 Release Integrity
 
@@ -240,14 +240,14 @@
 
 
 
-
+
 
 
 
-
+
 
 
-
+
 
 Mirrors
 
@@ -263,8 +263,8 @@
encounter a problem with this mirror, please select another
mirror.  If all mirrors are failing, there are backup
mirrors (at the end of the mirrors list) that should be
-   available.[if-any logo]
-
+   available.[if-any logo]
+
 [end]
 
 
@@ -279,7 +279,7 @@
[for backup][backup] (backup)[end]
[end]
  
-
+
 
 
   
@@ -290,16 +290,16 @@
 
 
 
-
+
 
 
 
-
+
 
 
-
-
-5.5.17
+
+
+5.5.20
 
 
 
@@ -309,15 +309,15 @@
 
 
   
-  Please see the 
-  README
+  Please see the 
+  README
   file for packaging information.  It explains what every distribution 
contains.
   
 
-  
+  
 
 
-
+
 
 Binary Distributions
 
@@ -331,19 +331,19 @@
 Core:
   
   
-  zip 
-  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17.zip.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17.zip.MD5";>md5)
+  zip 
+  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.zip.asc";>pgp,
 
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.zip.MD5";>md5)
   
   
-  tar.gz
 
-  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17.tar.gz.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17.tar.gz.MD5";>md5)
+  tar.gz
 
+  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.tar.gz.asc";>pgp,
 
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.tar.gz.MD5";>md5)
   
   
-  Windows 
Executable 
-  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17.exe.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17.exe.MD5";>md5)
+  Windows 
Executable 
+  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.exe.asc";>pgp,
 
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.exe.MD5";>md5)
   
   
 
@@ -351,28 +351,28 @@
 Deployer: 
   
   
-  zip
 
-  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17-deployer.zip.asc";>pgp,
 
-   http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17-deployer.zip.MD5";>md5)
+  zip
 
+  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.zip.asc";>pgp,
 
+   http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.zip.MD5";>md5)
   
   
-  tar.gz
 
-  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17-deployer.tar.gz.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17-deployer.tar.gz.MD5";>md5)
+  tar.gz
 
+  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.tar.gz.asc";>pgp,
 
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.tar.gz.MD5";>md5)
   
   
 
 Embedded:
   
   

svn commit: r450860 - /tomcat/site/trunk/xdocs/download-55.xml

2006-09-28 Thread fhanik
Author: fhanik
Date: Thu Sep 28 07:18:10 2006
New Revision: 450860

URL: http://svn.apache.org/viewvc?view=rev&rev=450860
Log:
5.5.20 is the new release

Modified:
tomcat/site/trunk/xdocs/download-55.xml

Modified: tomcat/site/trunk/xdocs/download-55.xml
URL: 
http://svn.apache.org/viewvc/tomcat/site/trunk/xdocs/download-55.xml?view=diff&rev=450860&r1=450859&r2=450860
==
--- tomcat/site/trunk/xdocs/download-55.xml (original)
+++ tomcat/site/trunk/xdocs/download-55.xml Thu Sep 28 07:18:10 2006
@@ -15,7 +15,7 @@
   
   
 http://www.apache.org/dist/tomcat/tomcat-5/KEYS";>KEYS |
-5.5.17 |
+5.5.20 |
 5.0.30-beta |
 5.0.28 |
 http://archive.apache.org/dist/tomcat/tomcat-5";>Archives
@@ -57,11 +57,11 @@
   
   
 
-  
-  
+  
+  
   
-  Please see the 
-  README
+  Please see the 
+  README
   file for packaging information.  It explains what every distribution 
contains.
   
 
@@ -70,19 +70,19 @@
 Core:
   
   
-  zip 
-  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17.zip.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17.zip.MD5";>md5)
+  zip 
+  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.zip.asc";>pgp,
 
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.zip.MD5";>md5)
   
   
-  tar.gz
 
-  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17.tar.gz.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17.tar.gz.MD5";>md5)
+  tar.gz
 
+  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.tar.gz.asc";>pgp,
 
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.tar.gz.MD5";>md5)
   
   
-  Windows 
Executable 
-  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17.exe.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17.exe.MD5";>md5)
+  Windows 
Executable 
+  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.exe.asc";>pgp,
 
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.exe.MD5";>md5)
   
   
 
@@ -90,28 +90,28 @@
 Deployer: 
   
   
-  zip
 
-  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17-deployer.zip.asc";>pgp,
 
-   http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17-deployer.zip.MD5";>md5)
+  zip
 
+  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.zip.asc";>pgp,
 
+   http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.zip.MD5";>md5)
   
   
-  tar.gz
 
-  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17-deployer.tar.gz.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17-deployer.tar.gz.MD5";>md5)
+  tar.gz
 
+  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.tar.gz.asc";>pgp,
 
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.tar.gz.MD5";>md5)
   
   
 
 Embedded:
   
   
-  zip
 
-  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17-embed.zip.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17-embed.zip.MD5";>md5)
+  zip
 
+  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-embed.zip.asc";>pgp,
 
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-embed.zip.MD5";>md5)
   
   
-  tar.gz
 
-  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17-embed.tar.gz.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17-embed.tar.gz.MD5";>md5)
+  tar.gz
 
+  (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-embed.tar.gz.asc";>pgp,
 
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-embed.tar.gz.MD5";>md5)
   
   
 
@@ -119,63 +119,63 @@
 Administration Web Application:
   
   
-zip
 
-(http://www.apache.org/dist/tomcat/tomcat-5/v5.5.17/bin/apache-tomcat-5.5.17-admin.zip.asc";>pgp,
 
-

svn commit: r450897 - in /tomcat/tc6.0.x/trunk/java/org/apache/jasper: EmbeddedServletOptions.java JspC.java Options.java resources/LocalStrings.properties servlet/JspServletWrapper.java

2006-09-28 Thread remm
Author: remm
Date: Thu Sep 28 08:28:05 2006
New Revision: 450897

URL: http://svn.apache.org/viewvc?view=rev&rev=450897
Log:
- Add a new init param for controlling display of source fragments.

Modified:
tomcat/tc6.0.x/trunk/java/org/apache/jasper/EmbeddedServletOptions.java
tomcat/tc6.0.x/trunk/java/org/apache/jasper/JspC.java
tomcat/tc6.0.x/trunk/java/org/apache/jasper/Options.java

tomcat/tc6.0.x/trunk/java/org/apache/jasper/resources/LocalStrings.properties
tomcat/tc6.0.x/trunk/java/org/apache/jasper/servlet/JspServletWrapper.java

Modified: 
tomcat/tc6.0.x/trunk/java/org/apache/jasper/EmbeddedServletOptions.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/jasper/EmbeddedServletOptions.java?view=diff&rev=450897&r1=450896&r2=450897
==
--- tomcat/tc6.0.x/trunk/java/org/apache/jasper/EmbeddedServletOptions.java 
(original)
+++ tomcat/tc6.0.x/trunk/java/org/apache/jasper/EmbeddedServletOptions.java Thu 
Sep 28 08:28:05 2006
@@ -179,6 +179,13 @@
  */
 private boolean xpoweredBy;
 
+/**
+ * Should we include a source fragment in exception messages, which could 
be displayed
+ * to the developer ?
+ */
+private boolean displaySourceFragment = true;
+
+
 public String getProperty(String name ) {
 return settings.getProperty( name );
 }
@@ -368,6 +375,14 @@
 }
 
 /**
+ * Should we include a source fragment in exception messages, which could 
be displayed
+ * to the developer ?
+ */
+public boolean getDisplaySourceFragment() {
+return displaySourceFragment;
+}
+
+/**
  * Create an EmbeddedServletOptions object using data available from
  * ServletConfig and ServletContext. 
  */
@@ -649,6 +664,19 @@
 } else {
 if (log.isWarnEnabled()) {
 log.warn(Localizer.getMessage("jsp.warning.xpoweredBy"));
+}
+}
+}
+
+String displaySourceFragment = 
config.getInitParameter("displaySourceFragment"); 
+if (displaySourceFragment != null) {
+if (displaySourceFragment.equalsIgnoreCase("true")) {
+this.displaySourceFragment = true;
+} else if (displaySourceFragment.equalsIgnoreCase("false")) {
+this.displaySourceFragment = false;
+} else {
+if (log.isWarnEnabled()) {
+
log.warn(Localizer.getMessage("jsp.warning.displaySourceFragment"));
 }
 }
 }

Modified: tomcat/tc6.0.x/trunk/java/org/apache/jasper/JspC.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/jasper/JspC.java?view=diff&rev=450897&r1=450896&r2=450897
==
--- tomcat/tc6.0.x/trunk/java/org/apache/jasper/JspC.java (original)
+++ tomcat/tc6.0.x/trunk/java/org/apache/jasper/JspC.java Thu Sep 28 08:28:05 
2006
@@ -385,6 +385,10 @@
 this.xpoweredBy = xpoweredBy;
 }
 
+public boolean getDisplaySourceFragment() {
+return true;
+}
+
 public boolean getErrorOnUseBeanInvalidClassAttribute() {
 return errorOnUseBeanInvalidClassAttribute;
 }

Modified: tomcat/tc6.0.x/trunk/java/org/apache/jasper/Options.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/jasper/Options.java?view=diff&rev=450897&r1=450896&r2=450897
==
--- tomcat/tc6.0.x/trunk/java/org/apache/jasper/Options.java (original)
+++ tomcat/tc6.0.x/trunk/java/org/apache/jasper/Options.java Thu Sep 28 
08:28:05 2006
@@ -75,6 +75,12 @@
 public boolean getDevelopment();
 
 /**
+ * Should we include a source fragment in exception messages, which could 
be displayed
+ * to the developer ?
+ */
+public boolean getDisplaySourceFragment();
+
+/**
  * Is the generation of SMAP info for JSR45 debugging suppressed?
  */
 public boolean isSmapSuppressed();

Modified: 
tomcat/tc6.0.x/trunk/java/org/apache/jasper/resources/LocalStrings.properties
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/jasper/resources/LocalStrings.properties?view=diff&rev=450897&r1=450896&r2=450897
==
--- 
tomcat/tc6.0.x/trunk/java/org/apache/jasper/resources/LocalStrings.properties 
(original)
+++ 
tomcat/tc6.0.x/trunk/java/org/apache/jasper/resources/LocalStrings.properties 
Thu Sep 28 08:28:05 2006
@@ -155,6 +155,7 @@
 jsp.warning.dumpSmap=Warning: Invalid value for the initParam dumpSmap. Will 
use the default value of \"false\"
 jsp.warning.genchararray=Warning: Invalid value for the initParam 
genStrAsCharArray. Will use the default value of \"false\"
 jsp.warning.suppressSmap=Warning: Invalid value for the 

org.apache.coyote.tomcat5.CoyoteInputStream.close()

2006-09-28 Thread Tim Koop

Hi everyone.

The Javadoc comment on 
org.apache.coyote.tomcat5.CoyoteInputStream.close() says this:


"Close the stream Since we re-cycle, we can't allow the call to 
super.close() which would permantely disable us."


I suspect a call to the underlying ServletInputStream.close() could be 
quite handy in some circumstances.  You might want to close the actual 
stream if someone is sending you a few GB of data and you actually want 
to close it.


I'm not exactly sure the best way to do this.  Perhaps CoyoteInputStream 
could have a method closeServletInputStream(), which could be called by 
casting request.getInputStream() to a CoyoteInputStream.


Any other thoughts?

--
Tim Koop

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



DO NOT REPLY [Bug 40633] New: - DefaultContext tag still referenced in doc.

2006-09-28 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG·
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND·
INSERTED IN THE BUG DATABASE.

http://issues.apache.org/bugzilla/show_bug.cgi?id=40633

   Summary: DefaultContext tag still referenced in doc.
   Product: Tomcat 5
   Version: 5.5.18
  Platform: All
OS/Version: All
Status: NEW
  Severity: minor
  Priority: P5
 Component: Webapps:Documentation
AssignedTo: tomcat-dev@jakarta.apache.org
ReportedBy: [EMAIL PROTECTED]


The  tag is still referenced in several places in the Tomcat
doc, even though it has been replaced by the conf/context.xml file.  I've found
references in the following doc source files:

container/webapps/docs/jndi-resources-howto.xml
container/webapps/docs/config/context.xml
container/webapps/docs/config/engine.xml
container/webapps/docs/config/globalresources.xml
container/webapps/docs/config/host.xml
container/webapps/docs/funcspecs/mbean-names.xml

This problem also exists in the recent 5.5.20 release.

-- 
Configure bugmail: http://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug, or are watching the assignee.

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



ANN] Apache Tomcat v5.5.20 Now Available

2006-09-28 Thread Filip Hanik - Dev Lists

The Apache Tomcat team is pleased to announce the immediate availability
of version 5.5.20 of the Apache Tomcat server.

This release contains dozens of important bug fixes and improvements to 
the Tomcat server.


Release Notes: http://tomcat.apache.org/tomcat-5.5-doc/RELEASE-NOTES

Change Log: http://tomcat.apache.org/tomcat-5.5-doc/changelog.html

Downloads: http://tomcat.apache.org/download-55.cgi

The mirrors are currently updating their content with this latest stable 
release. Please be patient if the mirror you are accessing has not yet been 
updated.

For previous releases of Tomcat, please visit
http://archive.apache.org/dist/tomcat/tomcat-5/

Thank you,

-- The Apache Tomcat Team




-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



svn commit: r450967 - in /tomcat/tc6.0.x/trunk/java/org/apache/catalina: CometEvent.java CometFilter.java CometFilterChain.java CometProcessor.java

2006-09-28 Thread remm
Author: remm
Date: Thu Sep 28 11:51:22 2006
New Revision: 450967

URL: http://svn.apache.org/viewvc?view=rev&rev=450967
Log:
- Javadoc update.

Modified:
tomcat/tc6.0.x/trunk/java/org/apache/catalina/CometEvent.java
tomcat/tc6.0.x/trunk/java/org/apache/catalina/CometFilter.java
tomcat/tc6.0.x/trunk/java/org/apache/catalina/CometFilterChain.java
tomcat/tc6.0.x/trunk/java/org/apache/catalina/CometProcessor.java

Modified: tomcat/tc6.0.x/trunk/java/org/apache/catalina/CometEvent.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/catalina/CometEvent.java?view=diff&rev=450967&r1=450966&r2=450967
==
--- tomcat/tc6.0.x/trunk/java/org/apache/catalina/CometEvent.java (original)
+++ tomcat/tc6.0.x/trunk/java/org/apache/catalina/CometEvent.java Thu Sep 28 
11:51:22 2006
@@ -78,33 +78,40 @@
 
 
 /**
- * Returns the HttpServletRequest or the last HttpServletRequestWrapper if 
a filter was applied
+ * Returns the HttpServletRequest.
+ * 
  * @return HttpServletRequest
  */
 public HttpServletRequest getHttpServletRequest();
 
 /**
- * Returns the HttpServletResponse or the last HttpServletResponseWrapper
+ * Returns the HttpServletResponse.
+ * 
  * @return HttpServletResponse
  */
 public HttpServletResponse getHttpServletResponse();
 
 /**
- * Returns the event type
+ * Returns the event type.
+ * 
  * @return EventType
  */
 public EventType getEventType();
 
 /**
- * Returns 
+ * Returns the sub type of this event.
+ * 
  * @return EventSubType
  */
 public EventSubType getEventSubType();
 
 /**
  * Ends the Comet session. This signals to the container that 
- * the container wants to end the comet session.
- * The container may invoke event(CometEvent.END) synchronously or 
asynchronously
+ * the container wants to end the comet session. This will send back to the
+ * client a notice that the server has no more data to send as part of this
+ * request. The servlet should perform any needed cleanup as if it had 
recieved
+ * an END or ERROR event. 
+ * 
  * @throws IOException if an IO exception occurs
  */
 public void close() throws IOException;
@@ -119,6 +126,7 @@
  * web application SHOULD NOT attempt to reuse the request and response 
objects after a timeout
  * as the error(HttpServletRequest, HttpServletResponse) 
method indicates.
  * This method should not be called asynchronously, as that will have no 
effect.
+ * 
  * @param timeout The timeout in milliseconds for this connection, must be 
a positive value, larger than 0
  * @throws IOException An IOException may be thrown to indicate an IO 
error, 
  * or that the EOF has been reached on the connection

Modified: tomcat/tc6.0.x/trunk/java/org/apache/catalina/CometFilter.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/catalina/CometFilter.java?view=diff&rev=450967&r1=450966&r2=450967
==
--- tomcat/tc6.0.x/trunk/java/org/apache/catalina/CometFilter.java (original)
+++ tomcat/tc6.0.x/trunk/java/org/apache/catalina/CometFilter.java Thu Sep 28 
11:51:22 2006
@@ -19,19 +19,63 @@
 
 import java.io.IOException;
 
-import javax.servlet.FilterChain;
+import javax.servlet.Filter;
 import javax.servlet.ServletException;
 
 /**
- * The CometFilter interface.
+ * A Comet filter, similar to regular filters, performs filtering tasks on 
either 
+ * the request to a resource (a Comet servlet), or on the response from a 
resource, or both.
+ * 
+ * Filters perform filtering in the doFilterEvent method. Every 
Filter has access to 
+ * a FilterConfig object from which it can obtain its initialization 
parameters, a
+ * reference to the ServletContext which it can use, for example, to load 
resources
+ * needed for filtering tasks.
+ * 
+ * Filters are configured in the deployment descriptor of a web application
+ * 
+ * Examples that have been identified for this design are
+ * 1) Authentication Filters 
+ * 2) Logging and Auditing Filters 
+ * 3) Image conversion Filters 
+ * 4) Data compression Filters 
+ * 5) Encryption Filters 
+ * 6) Tokenizing Filters 
+ * 7) Filters that trigger resource access events 
+ * 8) XSL/T filters 
+ * 9) Mime-type chain Filter 
+ * 
  * 
  * @author Remy Maucherat
  * @author Filip Hanik
  */
-public interface CometFilter {
+public interface CometFilter extends Filter {
 
 
-public void doFilterEvent(CometEvent event, CometFilterChain chain) throws 
IOException, ServletException;
+/**
+ * The doFilterEvent method of the CometFilter is called by 
the container
+ * each time a request/response pair is passed through the chain due
+ * to a client event for a resource at the end of the

svn commit: r450977 - /tomcat/tc6.0.x/trunk/BUILDING.txt

2006-09-28 Thread remm
Author: remm
Date: Thu Sep 28 12:24:24 2006
New Revision: 450977

URL: http://svn.apache.org/viewvc?view=rev&rev=450977
Log:
- Add building instructions.

Modified:
tomcat/tc6.0.x/trunk/BUILDING.txt

Modified: tomcat/tc6.0.x/trunk/BUILDING.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/BUILDING.txt?view=diff&rev=450977&r1=450976&r2=450977
==
--- tomcat/tc6.0.x/trunk/BUILDING.txt (original)
+++ tomcat/tc6.0.x/trunk/BUILDING.txt Thu Sep 28 12:24:24 2006
@@ -1,2 +1,121 @@
+$Id: BUILDING.txt 432252 2006-08-17 14:41:02Z jfclere $
+
+
+Building The Apache Tomcat 6.0 Servlet/JSP Container
+
+
+This subproject contains the source code for Tomcat 6.0, a container that
+implements the Servlet 2.5 and JSP 2.1 specifications from the Java
+Community Process .  In order to build a binary
+distribution version of the container from a source distribution, 
+do the following:
+
+
+(0) Download and Install a Java Development Kit
+
+* If the JDK is already installed, skip to (1).
+
+* Download a Java Development Kit (JDK) release (version 1.5.x or later) from:
+
+http://java.sun.com/j2se/
+
+* Install the JDK according to the instructions included with the release.
+
+* Set an environment variable JAVA_HOME to the pathname of the directory
+  into which you installed the JDK release.
+
+
+(1) Install Apache Ant 1.6.x on your computer
+
+* If Apache Ant 1.6.x is already installed on your computer, skip to (2).
+
+* Download a binary distribution of Ant 1.6.x from:
+
+http://ant.apache.org/bindownload.cgi
+
+* Unpack the binary distribution into a convenient location so that the
+  Ant release resides in its own directory (conventionally named
+  "apache-ant-[version]").  For the purposes of the remainder of this document,
+  the symbolic name "${ant.home}" is used to refer to the full pathname of
+  the release directory.
+
+* Create an ANT_HOME environment variable to point the directory
+  ${ant.home}.
+
+* Modify the PATH environment variable to include the directory
+  ${ant.home}/bin in its list.  This makes the "ant" command line script
+  available, which will be used to actually perform the build.
+
+
+(2) Building Tomcat 6.0
+
+(2.1) Checkout or obtain the source code for Tomcat 6.0
+
+* Tomcat SVN repository URL:
+  http://svn.apache.org/repos/asf/tomcat/tc6.0.x/
+
+* Download a source package from:
+  http://tomcat.apache.org/download-60.cgi
+
+* Checkout the source using SVN, selecting the desired version or
+  branch (current development source is at 
+  http://svn.apache.org/repos/asf/tomcat/tc6.0.x/trunk/), or 
+  unpack the source package. The location where the source has been
+  placed will be referred as ${tomcat.source}.
+
+(2.2) Building
+
+* Go to that directory, and do:
+
+cd ${tomcat.source}
+ant download
+ant
+
+* NOTE: Users accessing the Internet through a proxy must use a properties
+  file to indicate to Ant the proxy configuration. Read below.
+
+* WARNING: Running this command will download binaries to the /usr/share/java 
+  directory. Make sure this is appropriate to do on your computer. On Windows, 
+  this usually corresponds to the "C:\usr\share\java" directory, unless Cygwin 
+  is used. Read below to customize the directory used to download the binaries.
+
+* The build can be controlled by creating a ${tomcat.source}/build.properties
+  file, and adding the following content to it:
+
+# - Proxy setup -
+# Uncomment if using a proxy server
+#proxy.host=proxy.domain
+#proxy.port=8080
+#proxy.use=on
+
+# - Default Base Path for Dependent Packages -
+# Replace this path with the directory path where dependencies binaries
+# should be downloaded
+base.path=/usr/share/java
+
+
+(3) Updating sources
+
+It is recommended that you regularly update the downloaded Tomcat 6 sources
+using your SVN client.
+
+(4) Rebuilds
+
+For a quick rebuild of only modified code you can use:
+   
+cd ${tomcat.source}
+ant
+
+(5) Building the servlet and jsp API documentation
+
+The documentation can be easly built:
+
+cd ${tomcat.source}
+ant -f dist.xml dist-javadoc
+
+(6) Building a release running tests:
+
+cd ${tomcat.source}
+ant -f dist.xml release
 
 



-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



svn commit: r451035 - in /tomcat/tc6.0.x/trunk/java/org/apache/catalina: servlets/CGIServlet.java servlets/DefaultServlet.java servlets/InvokerServlet.java servlets/WebdavServlet.java ssi/SSIServlet.j

2006-09-28 Thread remm
Author: remm
Date: Thu Sep 28 15:00:56 2006
New Revision: 451035

URL: http://svn.apache.org/viewvc?view=rev&rev=451035
Log:
- Exception processing cleanup, as suggested by one guy in the past.

Modified:
tomcat/tc6.0.x/trunk/java/org/apache/catalina/servlets/CGIServlet.java
tomcat/tc6.0.x/trunk/java/org/apache/catalina/servlets/DefaultServlet.java
tomcat/tc6.0.x/trunk/java/org/apache/catalina/servlets/InvokerServlet.java
tomcat/tc6.0.x/trunk/java/org/apache/catalina/servlets/WebdavServlet.java
tomcat/tc6.0.x/trunk/java/org/apache/catalina/ssi/SSIServlet.java

Modified: tomcat/tc6.0.x/trunk/java/org/apache/catalina/servlets/CGIServlet.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/catalina/servlets/CGIServlet.java?view=diff&rev=451035&r1=451034&r2=451035
==
--- tomcat/tc6.0.x/trunk/java/org/apache/catalina/servlets/CGIServlet.java 
(original)
+++ tomcat/tc6.0.x/trunk/java/org/apache/catalina/servlets/CGIServlet.java Thu 
Sep 28 15:00:56 2006
@@ -294,22 +294,13 @@
 if (servletName.startsWith("org.apache.catalina.INVOKER."))
 throw new UnavailableException
 ("Cannot invoke CGIServlet through the invoker");
-
-boolean passShellEnvironment = false;
 
 // Set our properties from the initialization parameters
-String value = null;
-try {
-value = getServletConfig().getInitParameter("debug");
-debug = Integer.parseInt(value);
-cgiPathPrefix =
-getServletConfig().getInitParameter("cgiPathPrefix");
-value = 
getServletConfig().getInitParameter("passShellEnvironment");
-passShellEnvironment = Boolean.valueOf(value).booleanValue();
-} catch (Throwable t) {
-//NOOP
-}
-log("init: loglevel set to " + debug);
+if (getServletConfig().getInitParameter("debug") != null)
+debug = 
Integer.parseInt(getServletConfig().getInitParameter("debug"));
+cgiPathPrefix = getServletConfig().getInitParameter("cgiPathPrefix");
+boolean passShellEnvironment = 
+
Boolean.valueOf(getServletConfig().getInitParameter("passShellEnvironment")).booleanValue();
 
 if (passShellEnvironment) {
 try {
@@ -321,14 +312,12 @@
 }
 }
 
-value = getServletConfig().getInitParameter("executable");
-if (value != null) {
-cgiExecutable = value;
+if (getServletConfig().getInitParameter("executable") != null) {
+cgiExecutable = getServletConfig().getInitParameter("executable");
 }
 
-value = getServletConfig().getInitParameter("parameterEncoding");
-if (value != null) {
-parameterEncoding = value;
+if (getServletConfig().getInitParameter("parameterEncoding") != null) {
+parameterEncoding = 
getServletConfig().getInitParameter("parameterEncoding");
 }
 
 }
@@ -602,43 +591,40 @@
 }
  
 if (debug >= 10) {
-try {
-ServletOutputStream out = res.getOutputStream();
-out.println("$Name$");
-out.println("$Header$");
-
-if (cgiEnv.isValid()) {
-out.println(cgiEnv.toString());
-} else {
-out.println("");
-out.println("CGI script not found or not specified.");
-out.println("");
-out.println("");
-out.println("Check the HttpServletRequest ");
-out.println("pathInfo ");
-out.println("property to see if it is what you meant ");
-out.println("it to be.  You must specify an existant ");
-out.println("and executable file as part of the ");
-out.println("path-info.");
-out.println("");
-out.println("");
-out.println("For a good discussion of how CGI scripts ");
-out.println("work and what their environment variables ");
-out.println("mean, please visit the http://cgi-spec.golux.com\";>CGI ");
-out.println("Specification page.");
-out.println("");
 
-}
+ServletOutputStream out = res.getOutputStream();
+out.println("$Name$");
+out.println("$Header$");
+
+if (cgiEnv.isValid()) {
+out.println(cgiEnv.toString());
+} else {
+out.println("");
+out.println("CGI script not found or not specified.");
+out.println("");
+out.println("");
+out.println("Check the HttpServletRequest ");
+out.println("pathInfo ");
+out.println("

svn commit: r451049 - in /tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp: AjpAprProcessor.java AjpAprProtocol.java AjpMessage.java AjpProcessor.java AjpProtocol.java

2006-09-28 Thread remm
Author: remm
Date: Thu Sep 28 15:29:40 2006
New Revision: 451049

URL: http://svn.apache.org/viewvc?view=rev&rev=451049
Log:
- Add the new packetSize attribute.

Modified:
tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp/AjpAprProcessor.java
tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp/AjpAprProtocol.java
tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp/AjpMessage.java
tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp/AjpProcessor.java
tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp/AjpProtocol.java

Modified: tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp/AjpAprProcessor.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp/AjpAprProcessor.java?view=diff&rev=451049&r1=451048&r2=451049
==
--- tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp/AjpAprProcessor.java 
(original)
+++ tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp/AjpAprProcessor.java Thu 
Sep 28 15:29:40 2006
@@ -73,7 +73,7 @@
 // --- Constructors
 
 
-public AjpAprProcessor(AprEndpoint endpoint) {
+public AjpAprProcessor(int packetSize, AprEndpoint endpoint) {
 
 this.endpoint = endpoint;
 
@@ -85,6 +85,10 @@
 response.setOutputBuffer(new SocketOutputBuffer());
 request.setResponse(response);
 
+requestHeaderMessage = new AjpMessage(packetSize);
+responseHeaderMessage = new AjpMessage(packetSize);
+bodyMessage = new AjpMessage(packetSize);
+
 if (endpoint.getFirstReadTimeout() > 0) {
 readTimeout = endpoint.getFirstReadTimeout() * 1000;
 } else {
@@ -92,9 +96,9 @@
 }
 
 // Allocate input and output buffers
-inputBuffer = ByteBuffer.allocateDirect(Constants.MAX_PACKET_SIZE * 2);
+inputBuffer = ByteBuffer.allocateDirect(packetSize * 2);
 inputBuffer.limit(0);
-outputBuffer = ByteBuffer.allocateDirect(Constants.MAX_PACKET_SIZE * 
2);
+outputBuffer = ByteBuffer.allocateDirect(packetSize * 2);
 
 // Cause loading of HexUtils
 int foo = HexUtils.DEC[0];
@@ -131,19 +135,19 @@
  * processing of the first message of a "request", so it might not be a 
request
  * header. It will stay unchanged during the processing of the whole 
request.
  */
-protected AjpMessage requestHeaderMessage = new AjpMessage();
+protected AjpMessage requestHeaderMessage = null;
 
 
 /**
  * Message used for response header composition.
  */
-protected AjpMessage responseHeaderMessage = new AjpMessage();
+protected AjpMessage responseHeaderMessage = null;
 
 
 /**
  * Body message.
  */
-protected AjpMessage bodyMessage = new AjpMessage();
+protected AjpMessage bodyMessage = null;
 
 
 /**
@@ -267,7 +271,7 @@
 static {
 
 // Set the get body message buffer
-AjpMessage getBodyMessage = new AjpMessage();
+AjpMessage getBodyMessage = new AjpMessage(128);
 getBodyMessage.reset();
 getBodyMessage.appendByte(Constants.JK_AJP13_GET_BODY_CHUNK);
 getBodyMessage.appendInt(Constants.MAX_READ_SIZE);
@@ -278,7 +282,7 @@
 getBodyMessage.getLen());
 
 // Set the read body message buffer
-AjpMessage pongMessage = new AjpMessage();
+AjpMessage pongMessage = new AjpMessage(128);
 pongMessage.reset();
 pongMessage.appendByte(Constants.JK_AJP13_CPONG_REPLY);
 pongMessage.end();
@@ -287,7 +291,7 @@
 pongMessage.getLen());
 
 // Allocate the end message array
-AjpMessage endMessage = new AjpMessage();
+AjpMessage endMessage = new AjpMessage(128);
 endMessage.reset();
 endMessage.appendByte(Constants.JK_AJP13_END_RESPONSE);
 endMessage.appendByte(1);
@@ -347,8 +351,6 @@
 
 // Error flag
 error = false;
-
-long soTimeout = endpoint.getSoTimeout();
 
 int limit = 0;
 if (endpoint.getFirstReadTimeout() > 0) {

Modified: tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp/AjpAprProtocol.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp/AjpAprProtocol.java?view=diff&rev=451049&r1=451048&r2=451049
==
--- tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp/AjpAprProtocol.java 
(original)
+++ tomcat/tc6.0.x/trunk/java/org/apache/coyote/ajp/AjpAprProtocol.java Thu Sep 
28 15:29:40 2006
@@ -108,6 +108,12 @@
 
 
 /**
+ * AJP packet size.
+ */
+protected int packetSize = Constants.MAX_PACKET_SIZE;
+
+
+/**
  * Adapter which will process the requests recieved by this endpoint.
  */
 private Adapter adapter;
@@ -417,6 +423,16 @@
 }
 
 
+public int getPacketSize() {
+return packetSize;
+}
+
+
+public void setPacketSize(

Re: ANN] Apache Tomcat v5.5.20 Now Available

2006-09-28 Thread David Rees

On 9/28/06, Filip Hanik - Dev Lists <[EMAIL PROTECTED]> wrote:

The Apache Tomcat team is pleased to announce the immediate availability
of version 5.5.20 of the Apache Tomcat server.


The links to the md5sum files are broken on the download page, they
end with .MD5 and should end with .md5.

-Dave

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



Re: ANN] Apache Tomcat v5.5.20 Now Available

2006-09-28 Thread Filip Hanik - Dev Lists

I will fix that, thanks for letting us know

FIlip

David Rees wrote:

On 9/28/06, Filip Hanik - Dev Lists <[EMAIL PROTECTED]> wrote:

The Apache Tomcat team is pleased to announce the immediate availability
of version 5.5.20 of the Apache Tomcat server.


The links to the md5sum files are broken on the download page, they
end with .MD5 and should end with .md5.

-Dave

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]





-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



svn commit: r451083 - in /tomcat/site/trunk: docs/download-55.html xdocs/download-55.xml

2006-09-28 Thread fhanik
Author: fhanik
Date: Thu Sep 28 18:59:21 2006
New Revision: 451083

URL: http://svn.apache.org/viewvc?view=rev&rev=451083
Log:
Fixed MD5 file extensions

Modified:
tomcat/site/trunk/docs/download-55.html
tomcat/site/trunk/xdocs/download-55.xml

Modified: tomcat/site/trunk/docs/download-55.html
URL: 
http://svn.apache.org/viewvc/tomcat/site/trunk/docs/download-55.html?view=diff&rev=451083&r1=451082&r2=451083
==
--- tomcat/site/trunk/docs/download-55.html (original)
+++ tomcat/site/trunk/docs/download-55.html Thu Sep 28 18:59:21 2006
@@ -333,17 +333,17 @@
   
   zip 
   (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.zip.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.zip.MD5";>md5)
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.zip.md5";>md5)
   
   
   tar.gz
 
   (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.tar.gz.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.tar.gz.MD5";>md5)
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.tar.gz.md5";>md5)
   
   
   Windows 
Executable 
   (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.exe.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.exe.MD5";>md5)
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20.exe.md5";>md5)
   
   
 
@@ -353,12 +353,12 @@
   
   zip
 
   (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.zip.asc";>pgp,
 
-   http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.zip.MD5";>md5)
+   http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.zip.md5";>md5)
   
   
   tar.gz
 
   (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.tar.gz.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.tar.gz.MD5";>md5)
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-deployer.tar.gz.md5";>md5)
   
   
 
@@ -367,12 +367,12 @@
   
   zip
 
   (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-embed.zip.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-embed.zip.MD5";>md5)
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-embed.zip.md5";>md5)
   
   
   tar.gz
 
   (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-embed.tar.gz.asc";>pgp,
 
-  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-embed.tar.gz.MD5";>md5)
+  http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-embed.tar.gz.md5";>md5)
   
   
 
@@ -382,12 +382,12 @@
   
 zip
 
 (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-admin.zip.asc";>pgp,
 
-http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-admin.zip.MD5";>md5)
+http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-admin.zip.md5";>md5)
   
   
 tar.gz
 
 (http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-admin.tar.gz.asc";>pgp,
 
-http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-admin.tar.gz.MD5";>md5)
+http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-admin.tar.gz.md5";>md5)
   
   
 
@@ -396,12 +396,12 @@
  
zip
 
(http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-compat.zip.asc";>pgp,
 
-   http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-compat.zip.MD5";>md5)
+   http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-compat.zip.md5";>md5)
  
  
tar.gz
 
(http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-compat.tar.gz.asc";>pgp,
 
-   http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-compat.tar.gz.MD5";>md5)
+   http://www.apache.org/dist/tomcat/tomcat-5/v5.5.20/bin/apache-tomcat-5.5.20-compat.tar.gz.md5";>md5)
  
  

@@ -410,7 +410,7 @@
  
  tar.

Re: [6.0] Updates

2006-09-28 Thread Costin Manolache

On 9/27/06, Remy Maucherat <[EMAIL PROTECTED]> wrote:


Peter Rossbach wrote:
> Hi Filip,
>
> I thing many people use the current cluster implementation. For those
> people I want spend my time to sync two branches :-)
> Some people ask me to start experiments with new Servlet and JSP API's
> or the new connector implementation but with
> the old cluster API. Let the user the choice,like APR or Java HTTP
> Connector.

This does not make much sense here, as the new implementation does the
exact same thing as the other one (unlike the connectors). Did you test
the new clustering ? How does it compare to the old one ?

There's no need for two clustering implementations, so one of them needs
to be chosen. The other one may be developed in the sandbox and provided
as an alternative (in a separate download), but I think that's time
which would be wasted. BTW, a major release is also the best opportunity
to make some changes in configuration. If it's not done now, then we
would have to keep both for a long time.



IMO both clustering implementations should be provided as separate
downloads.

No need to put them in sandbox ( since they were released in the past, it's
'proven' code ).
Not sure if they should be in separate repos or it's ok to have both of them
in the main tree.


Costin


DO NOT REPLY [Bug 40637] New: - java.io.IOException: Stream closed / JspWriterImpl.java:203

2006-09-28 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG·
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND·
INSERTED IN THE BUG DATABASE.

http://issues.apache.org/bugzilla/show_bug.cgi?id=40637

   Summary: java.io.IOException: Stream closed /
JspWriterImpl.java:203
   Product: Tomcat 5
   Version: 5.5.15
  Platform: PC
   URL: http://www.citycarshare.org/
OS/Version: Linux
Status: NEW
  Severity: minor
  Priority: P3
 Component: Jasper
AssignedTo: tomcat-dev@jakarta.apache.org
ReportedBy: [EMAIL PROTECTED]


I've been getting these exceptions in my logs for a while now.  I've done a LOT
of googling, but only find other people with these exceptions in their logs (and
no solutions).  I my case they seem to be causing "no harm" other than sysadmin
panic:


Sep 28, 2006 9:28:44 PM org.apache.jasper.runtime.PageContextImpl release
WARNING: Internal error flushing the buffer in release()
Sep 28, 2006 9:28:44 PM org.apache.catalina.core.StandardWrapperValve invoke
SEVERE: Servlet.service() for servlet jsp threw exception
java.io.IOException: Stream closed
at
org.apache.jasper.runtime.JspWriterImpl.ensureOpen(JspWriterImpl.java:203)
at
org.apache.jasper.runtime.JspWriterImpl.clearBuffer(JspWriterImpl.java:159)
at org.apache.jsp.index_jsp._jspService(org.apache.jsp.index_jsp:48)
at org.apache.jasper.runtime.HttpJspBase.service(HttpJspBase.java:97)
at javax.servlet.http.HttpServlet.service(HttpServlet.java:802)
at
org.apache.jasper.servlet.JspServletWrapper.service(JspServletWrapper.java:332)
at 
org.apache.jasper.servlet.JspServlet.serviceJspFile(JspServlet.java:314)
at org.apache.jasper.servlet.JspServlet.service(JspServlet.java:264)
at javax.servlet.http.HttpServlet.service(HttpServlet.java:802)
at
org.apache.catalina.core.ApplicationFilterChain.internalDoFilter(ApplicationFilterChain.java:252)
at
org.apache.catalina.core.ApplicationFilterChain.doFilter(ApplicationFilterChain.java:173)
at
org.apache.catalina.core.StandardWrapperValve.invoke(StandardWrapperValve.java:213)
at
org.apache.catalina.core.StandardContextValve.invoke(StandardContextValve.java:178)
at
org.apache.catalina.core.StandardHostValve.invoke(StandardHostValve.java:126)
at
org.apache.catalina.valves.ErrorReportValve.invoke(ErrorReportValve.java:105)
at
org.apache.catalina.core.StandardEngineValve.invoke(StandardEngineValve.java:107)
at
org.apache.catalina.connector.CoyoteAdapter.service(CoyoteAdapter.java:148)
at org.apache.jk.server.JkCoyoteHandler.invoke(JkCoyoteHandler.java:199)
at org.apache.jk.common.HandlerRequest.invoke(HandlerRequest.java:282)
at org.apache.jk.common.ChannelSocket.invoke(ChannelSocket.java:754)
at
org.apache.jk.common.ChannelSocket.processConnection(ChannelSocket.java:684)
at
org.apache.jk.common.ChannelSocket$SocketConnection.runIt(ChannelSocket.java:876)
at
org.apache.tomcat.util.threads.ThreadPool$ControlRunnable.run(ThreadPool.java:684)
at java.lang.Thread.run(Thread.java:595)


I guess I'm asking for a few more details, to be added in this exception, to
help all us folks track down the real cause.

--- tomcat/connectors/trunk/jni/jnirelease.sh (original)
+++ tomcat/connectors/trunk/jni/jnirelease.sh Thu Sep 28 02:47:44 2006
@@ -1,6 +1,6 @@
 #/bin/sh
 #
-# Copyright 1999-2005 The Apache Software Foundation
+# Copyright 1999-2006 The Apache Software Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,15 +14,46 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# APRDIR have to be the location of the APR sources
-APRDIR=$HOME/apr
-#
-# Replace JKJNIEXT with branche/or tag
-#  and JKJNIVER by the version like -1.1.0
-JKJNIEXT="trunk"
-JKJNIVER="-dev"
+# Default place to look for apr source.  Can be overridden with 
+#   --with-apr=[directory]
+apr_src_dir=../apr
+
+while test $# -gt 0 
+do
+  # Normalize
+  case "$1" in
+  -*=*) optarg=`echo "$1" | sed 's/[-_a-zA-Z0-9]*=//'` ;;
+  *) optarg= ;;
+  esac
+
+  case "$1" in
+  --with-apr=*)
+  apr_src_dir=$optarg
+  ;;
+  esac
+
+  shift
+done
+
+if test -d "$apr_src_dir"
+then
+  echo ""
+  echo "Looking for apr source in $apr_src_dir"
+else
+  echo ""
+  echo "Problem finding apr source in $apr_src_dir."
+  echo "Use:"
+  echo "  --with-apr=[directory]" 
+  exit 1
+fi
+
+# Replace JKJNIEXT with branch/or tag
+# and JKJNIVER by the version like 1.1.0
+JKJNIEXT=trunk
+JKJNIVER=current
+# JKJNIVER="1.1.5"
 SVNBASE=https://svn.apache.org/repos/asf/tomcat/connectors/
-JKJNIDIST=tomcat-connectors${JKJNIVER}
+JKJNIDIST=tomcat-connectors-${JKJNIVER}-src
 rm -rf ${JKJNIDIST}
 mkdir -p ${JKJNIDIST}/jni
 svn export $SVNBASE/${JKJNIEXT}/jni/native ${JKJNIDIST}/jni/native
@@ -31,15 +62,22 @@
 svn cat $SVNBASE/${JKJNIEXT}/NOTICE > ${JKJNIDIST}/NOTICE
 svn cat $SVNBASE/${JKJNIEXT}/jni/NOTICE.txt > ${JKJNIDIST}/NOTICE.txt
 svn cat $SVNBASE/${JKJNIEXT}/jni/README.txt > ${JKJNIDIST}/README.txt
-
+#
 # Prebuild
 cd ${JKJNIDIST}/jni/native
-# Adjust the location of APR sources
-./buildconf --with-apr=$APRDIR
+./buildconf --with-apr=$apr_src_dir
 cd ../../../
-# Create distribution
-tar cvf ${JKJNIDIST}.tar ${JKJNIDIST}
-gzip ${JKJNIDIST}.tar
-# Convert lineends to DOS
-perl $APRDIR/build/lineends.pl --cr ${JKJNIDIST}
-zip -9 -r  ${JKJNIDIST}.zip ${JKJNIDIST}
+# Create source distribution
+tar cfz ${JKJNIDIST}.tar.gz ${JKJNIDIST}
+#
+# Create Win32 source distribution
+JKJNIDIST=tomcat-connectors-${JKJNIVER}-win32-src
+rm -rf ${JKJNIDIST}
+mkdir -p ${JKJNIDIST}/jni
+svn export --native-eol CRLF $SVNBASE/${JKJNIEXT}/jni/native 
${JKJNIDIST}/jni/native
+svn cat $SVNBASE/${JKJNIEXT}/KEYS > ${JKJNIDIST}/KEYS
+svn cat $SVNBASE/${JKJNIEXT}/LICENSE > ${JKJNIDIST}/LICENSE
+svn cat $SVNBASE/${JKJNIEXT}/NOTICE > ${JKJNIDIST}/NOTICE
+svn cat $SVNBASE/${JKJNIEXT}/jni/NOTICE.txt > ${JKJNIDIST}/NOTICE.txt
+svn cat $SVNBASE/${JKJNIEXT}/jni/README.txt > ${JKJNIDIST}/README.txt
+zip -9rqo ${JKJNIDIST}.zip ${JKJNIDIST}



-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



svn commit: r450778 - /tomcat/connectors/trunk/jni/jnirelease.sh

2006-09-28 Thread mturk
Author: mturk
Date: Thu Sep 28 02:48:47 2006
New Revision: 450778

URL: http://svn.apache.org/viewvc?view=rev&rev=450778
Log:
Add executable property.

Modified:
tomcat/connectors/trunk/jni/jnirelease.sh   (props changed)

Propchange: tomcat/connectors/trunk/jni/jnirelease.sh
-- 
Configure bugmail: http://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug, or are watching the assignee.

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]